package cn.com.infosec.jce;

import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1InputStream;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1Set;
import cn.com.infosec.asn1.DEREncodable;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERNull;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.DEROctetString;
import cn.com.infosec.asn1.DEROutputStream;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.DERSet;
import cn.com.infosec.asn1.DERTaggedObject;
import cn.com.infosec.asn1.pkcs.ContentInfo;
import cn.com.infosec.asn1.pkcs.IssuerAndSerialNumber;
import cn.com.infosec.asn1.pkcs.PKCSObjectIdentifiers;
import cn.com.infosec.asn1.pkcs.SignedData;
import cn.com.infosec.asn1.pkcs.SignerInfo;
import cn.com.infosec.asn1.x509.AlgorithmIdentifier;
import cn.com.infosec.asn1.x509.CertificateList;
import cn.com.infosec.asn1.x509.X509CertificateStructure;
import cn.com.infosec.asn1.x509.X509Name;
import cn.com.infosec.jce.provider.X509CRLObject;
import cn.com.infosec.jce.provider.X509CertificateObject;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.math.BigInteger;
import java.security.NoSuchAlgorithmException;
import java.security.PrivateKey;
import java.security.Signature;
import java.security.cert.CRL;
import java.security.cert.Certificate;
import java.security.cert.CertificateParsingException;
import java.security.cert.X509CRL;
import java.security.cert.X509Certificate;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Enumeration;
import java.util.HashSet;
import java.util.Iterator;
import java.util.Set;

/** @deprecated */
public class PKCS7SignedData_BC implements PKCSObjectIdentifiers {
   private int version;
   private int signerversion;
   private Set digestalgos;
   private Collection certs;
   private Collection crls;
   private X509Certificate signCert;
   private byte[] digest;
   private String digestAlgorithm;
   private String digestEncryptionAlgorithm;
   private Signature sig;
   private transient PrivateKey privKey;
   private final String ID_PKCS7_DATA;
   private final String ID_PKCS7_SIGNED_DATA;
   private final String ID_MD5;
   private final String ID_MD2;
   private final String ID_SHA1;
   private final String ID_RSA;
   private final String ID_DSA;

   public PKCS7SignedData_BC(byte[] in) {
      this(in, "INFOSEC");
   }

   public PKCS7SignedData_BC(byte[] in, String provider) {
      this.ID_PKCS7_DATA = "1.2.840.113549.1.7.1";
      this.ID_PKCS7_SIGNED_DATA = "1.2.840.113549.1.7.2";
      this.ID_MD5 = "1.2.840.113549.2.5";
      this.ID_MD2 = "1.2.840.113549.2.2";
      this.ID_SHA1 = "1.3.14.3.2.26";
      this.ID_RSA = "1.2.840.113549.1.1.1";
      this.ID_DSA = "1.2.840.10040.4.1";
      ASN1InputStream var10000 = new ASN1InputStream(new ByteArrayInputStream(in));

      DERObject var19;
      try {
         var19 = var10000.readObject();
      } catch (IOException var8) {
         throw new SecurityException("can't decode PKCS7SignedData object");
      }

      DERObject in1 = var19;
      if (var19 instanceof ASN1Sequence) {
         ContentInfo in2;
         if (!(in2 = ContentInfo.getInstance(in1)).getContentType().equals(PKCSObjectIdentifiers.signedData)) {
            throw new SecurityException("Not a valid PKCS#7 signed-data object - wrong header " + in2.getContentType().getId());
         } else {
            SignedData var3 = SignedData.getInstance(in2.getContent());
            this.certs = new ArrayList();
            Enumeration in3;
            if (var3.getCertificates() != null) {
               in3 = ASN1Set.getInstance(var3.getCertificates()).getObjects();

               while(in3.hasMoreElements()) {
                  try {
                     this.certs.add(new X509CertificateObject(X509CertificateStructure.getInstance(in3.nextElement())));
                  } catch (CertificateParsingException var7) {
                     throw new SecurityException(var7.toString());
                  }
               }
            }

            this.crls = new ArrayList();
            if (var3.getCRLs() != null) {
               in3 = ASN1Set.getInstance(var3.getCRLs()).getObjects();

               while(in3.hasMoreElements()) {
                  this.crls.add(new X509CRLObject(CertificateList.getInstance(in3.nextElement())));
               }
            }

            this.version = var3.getVersion().getValue().intValue();
            this.digestalgos = new HashSet();
            Enumeration var4 = var3.getDigestAlgorithms().getObjects();

            while(var4.hasMoreElements()) {
               DERObjectIdentifier in4 = (DERObjectIdentifier)((ASN1Sequence)var4.nextElement()).getObjectAt(0);
               this.digestalgos.add(in4.getId());
            }

            ASN1Set in5;
            if ((in5 = var3.getSignerInfos()).size() != 1) {
               throw new SecurityException("This PKCS#7 object has multiple SignerInfos - only one is supported at this time");
            } else {
               SignerInfo in6;
               SignerInfo var10001 = in6 = SignerInfo.getInstance(in5.getObjectAt(0));
               this.signerversion = in6.getVersion().getValue().intValue();
               IssuerAndSerialNumber var15;
               BigInteger var18 = (var15 = var10001.getIssuerAndSerialNumber()).getCertificateSerialNumber().getValue();
               X509Principal var5;
               var5 = new X509Principal.<init>(var15.getName());
               Iterator var16 = this.certs.iterator();

               while(var16.hasNext()) {
                  X509Certificate var6;
                  if (var18.equals((var6 = (X509Certificate)var16.next()).getSerialNumber()) && var5.equals(var6.getIssuerDN())) {
                     this.signCert = var6;
                     break;
                  }
               }

               if (this.signCert != null) {
                  this.digestAlgorithm = in6.getDigestAlgorithm().getObjectId().getId();
                  this.digest = in6.getEncryptedDigest().getOctets();
                  this.digestEncryptionAlgorithm = in6.getDigestEncryptionAlgorithm().getObjectId().getId();
                  Signature in7;
                  Signature var20 = in7 = Signature.getInstance(this.getDigestAlgorithm(), provider);
                  this.sig = in7;
                  var20.initVerify(this.signCert.getPublicKey());
               } else {
                  throw new SecurityException("Can't find signing certificate with serial " + var18.toString(16));
               }
            }
         }
      } else {
         throw new SecurityException("Not a valid PKCS#7 object - not a sequence");
      }
   }

   public PKCS7SignedData_BC(PrivateKey privKey, Certificate[] certChain, String hashAlgorithm) {
      this(privKey, certChain, hashAlgorithm, "INFOSEC");
   }

   public PKCS7SignedData_BC(PrivateKey privKey, Certificate[] certChain, String hashAlgorithm, String provider) {
      this(privKey, certChain, (CRL[])null, hashAlgorithm, provider);
   }

   public PKCS7SignedData_BC(PrivateKey privKey, Certificate[] certChain, CRL[] crlList, String hashAlgorithm, String provider) {
      this.ID_PKCS7_DATA = "1.2.840.113549.1.7.1";
      this.ID_PKCS7_SIGNED_DATA = "1.2.840.113549.1.7.2";
      this.ID_MD5 = "1.2.840.113549.2.5";
      this.ID_MD2 = "1.2.840.113549.2.2";
      this.ID_SHA1 = "1.3.14.3.2.26";
      this.ID_RSA = "1.2.840.113549.1.1.1";
      this.ID_DSA = "1.2.840.10040.4.1";
      this.privKey = privKey;
      if (hashAlgorithm.equals("MD5")) {
         this.digestAlgorithm = "1.2.840.113549.2.5";
      } else if (hashAlgorithm.equals("MD2")) {
         this.digestAlgorithm = "1.2.840.113549.2.2";
      } else if (hashAlgorithm.equals("SHA")) {
         this.digestAlgorithm = "1.3.14.3.2.26";
      } else {
         if (!hashAlgorithm.equals("SHA1")) {
            throw new NoSuchAlgorithmException("Unknown Hash Algorithm " + hashAlgorithm);
         }

         this.digestAlgorithm = "1.3.14.3.2.26";
      }

      this.signerversion = 1;
      this.version = 1;
      this.certs = new ArrayList();
      this.crls = new ArrayList();
      HashSet hashAlgorithm1;
      HashSet var10002 = hashAlgorithm1 = new HashSet;
      hashAlgorithm1.<init>();
      this.digestalgos = hashAlgorithm1;
      var10002.add(this.digestAlgorithm);
      this.signCert = (X509Certificate)certChain[0];

      for(int hashAlgorithm2 = 0; hashAlgorithm2 < certChain.length; ++hashAlgorithm2) {
         this.certs.add(certChain[hashAlgorithm2]);
      }

      if (crlList != null) {
         for(int certChain1 = 0; certChain1 < crlList.length; ++certChain1) {
            this.crls.add(crlList[certChain1]);
         }
      }

      if ((this.digestEncryptionAlgorithm = privKey.getAlgorithm()).equals("RSA")) {
         this.digestEncryptionAlgorithm = "1.2.840.113549.1.1.1";
      } else {
         if (!this.digestEncryptionAlgorithm.equals("DSA")) {
            throw new NoSuchAlgorithmException("Unknown Key Algorithm " + this.digestEncryptionAlgorithm);
         }

         this.digestEncryptionAlgorithm = "1.2.840.10040.4.1";
      }

      Signature certChain2;
      Signature var10000 = certChain2 = Signature.getInstance(this.getDigestAlgorithm(), provider);
      this.sig = certChain2;
      var10000.initSign(privKey);
   }

   private DERObject getIssuer(byte[] enc) {
      IOException var10000;
      label32: {
         boolean var10001;
         ASN1Sequence var8;
         try {
            var8 = (ASN1Sequence)(new ASN1InputStream(new ByteArrayInputStream(enc))).readObject();
         } catch (IOException var4) {
            var10000 = var4;
            var10001 = false;
            break label32;
         }

         ASN1Sequence var5 = var8;

         boolean var9;
         try {
            var9 = var8.getObjectAt(0) instanceof DERTaggedObject;
         } catch (IOException var3) {
            var10000 = var3;
            var10001 = false;
            break label32;
         }

         byte enc1;
         if (var9) {
            enc1 = 3;
         } else {
            enc1 = 2;
         }

         try {
            return (DERObject)var5.getObjectAt(enc1);
         } catch (IOException var2) {
            var10000 = var2;
            var10001 = false;
         }
      }

      IOException var6 = var10000;
      throw new Error("IOException reading from ByteArray: " + var6);
   }

   public String getDigestAlgorithm() {
      String var1;
      String var10000 = var1 = this.digestAlgorithm;
      String var2 = this.digestEncryptionAlgorithm;
      if (var10000.equals("1.2.840.113549.2.5")) {
         var1 = "MD5";
      } else if (this.digestAlgorithm.equals("1.2.840.113549.2.2")) {
         var1 = "MD2";
      } else if (this.digestAlgorithm.equals("1.3.14.3.2.26")) {
         var1 = "SHA1";
      }

      if (this.digestEncryptionAlgorithm.equals("1.2.840.113549.1.1.1")) {
         var2 = "RSA";
      } else if (this.digestEncryptionAlgorithm.equals("1.2.840.10040.4.1")) {
         var2 = "DSA";
      }

      return var1 + "with" + var2;
   }

   public void reset() {
      Exception var10000;
      label28: {
         boolean var10001;
         PrivateKey var7;
         try {
            var7 = this.privKey;
         } catch (Exception var5) {
            var10000 = var5;
            var10001 = false;
            break label28;
         }

         PrivateKey var1 = var7;
         if (var7 == null) {
            try {
               this.sig.initVerify(this.signCert.getPublicKey());
            } catch (Exception var4) {
               var10000 = var4;
               var10001 = false;
               break label28;
            }
         } else {
            try {
               this.sig.initSign(var1);
            } catch (Exception var3) {
               var10000 = var3;
               var10001 = false;
               break label28;
            }
         }

         try {
            return;
         } catch (Exception var2) {
            var10000 = var2;
            var10001 = false;
         }
      }

      Exception var6 = var10000;
      throw new RuntimeException(var6.toString());
   }

   public Certificate[] getCertificates() {
      Collection var10000 = this.certs;
      return (X509Certificate[])var10000.toArray(new X509Certificate[var10000.size()]);
   }

   public Collection getCRLs() {
      return this.crls;
   }

   public X509Certificate getSigningCertificate() {
      return this.signCert;
   }

   public int getVersion() {
      return this.version;
   }

   public int getSigningInfoVersion() {
      return this.signerversion;
   }

   public void update(byte buf) {
      this.sig.update(buf);
   }

   public void update(byte[] buf, int off, int len) {
      this.sig.update(buf, off, len);
   }

   public boolean verify() {
      return this.sig.verify(this.digest);
   }

   public byte[] getEncoded() {
      Exception var10000;
      label184: {
         boolean var10001;
         PKCS7SignedData_BC var38;
         ASN1EncodableVector var40;
         try {
            var38 = this;
            this.digest = this.sig.sign();
            var40 = new ASN1EncodableVector;
         } catch (Exception var29) {
            var10000 = var29;
            var10001 = false;
            break label184;
         }

         ASN1EncodableVector var1 = var40;

         Iterator var39;
         try {
            var40.<init>();
            var39 = var38.digestalgos.iterator();
         } catch (Exception var28) {
            var10000 = var28;
            var10001 = false;
            break label184;
         }

         Iterator var2 = var39;

         label174:
         while(true) {
            boolean var41;
            try {
               var41 = var2.hasNext();
            } catch (Exception var26) {
               var10000 = var26;
               var10001 = false;
               break;
            }

            if (!var41) {
               DERSet var42;
               try {
                  var38 = this;
                  var42 = new DERSet;
               } catch (Exception var25) {
                  var10000 = var25;
                  var10001 = false;
                  break;
               }

               DERSet var35 = var42;

               DERSequence var45;
               try {
                  var42.<init>(var1);
                  var45 = new DERSequence;
               } catch (Exception var24) {
                  var10000 = var24;
                  var10001 = false;
                  break;
               }

               DERSequence var32 = var45;

               try {
                  var45.<init>(new DERObjectIdentifier("1.2.840.113549.1.7.1"));
                  var40 = new ASN1EncodableVector;
               } catch (Exception var23) {
                  var10000 = var23;
                  var10001 = false;
                  break;
               }

               ASN1EncodableVector var3 = var40;

               try {
                  var40.<init>();
                  var39 = var38.certs.iterator();
               } catch (Exception var22) {
                  var10000 = var22;
                  var10001 = false;
                  break;
               }

               Iterator var4 = var39;

               while(true) {
                  try {
                     var41 = var4.hasNext();
                  } catch (Exception var20) {
                     var10000 = var20;
                     var10001 = false;
                     break label174;
                  }

                  if (!var41) {
                     try {
                        var38 = this;
                        var42 = new DERSet;
                     } catch (Exception var19) {
                        var10000 = var19;
                        var10001 = false;
                        break label174;
                     }

                     DERSet var37 = var42;

                     try {
                        var42.<init>(var3);
                        var40 = new ASN1EncodableVector;
                     } catch (Exception var18) {
                        var10000 = var18;
                        var10001 = false;
                        break label174;
                     }

                     ASN1EncodableVector var10002 = var40;
                     ASN1EncodableVector var10003 = var40;
                     ASN1EncodableVector var10004 = var40;
                     ASN1EncodableVector var10005 = var40;
                     ASN1EncodableVector var10006 = var3 = var40;

                     try {
                        var10006.<init>();
                        var10005.add(new DERInteger(this.signerversion));
                        var10004.add(new IssuerAndSerialNumber(new X509Name((ASN1Sequence)this.getIssuer(this.signCert.getTBSCertificate())), new DERInteger(this.signCert.getSerialNumber())));
                        var10003.add(new AlgorithmIdentifier(new DERObjectIdentifier(this.digestAlgorithm), new DERNull()));
                        var10002.add(new AlgorithmIdentifier(new DERObjectIdentifier(this.digestEncryptionAlgorithm), new DERNull()));
                        var40.add(new DEROctetString(this.digest));
                        var40 = new ASN1EncodableVector;
                     } catch (Exception var17) {
                        var10000 = var17;
                        var10001 = false;
                        break label174;
                     }

                     ASN1EncodableVector var5;
                     var10002 = var5 = var40;

                     int var46;
                     try {
                        var5.<init>();
                        var5.add(new DERInteger(this.version));
                        var5.add(var35);
                        var10002.add(var32);
                        var40.add(new DERTaggedObject(false, 0, var37));
                        var46 = var38.crls.size();
                     } catch (Exception var16) {
                        var10000 = var16;
                        var10001 = false;
                        break label174;
                     }

                     ASN1EncodableVector var30;
                     ASN1EncodableVector var47;
                     if (var46 > 0) {
                        try {
                           var38 = this;
                           var40 = new ASN1EncodableVector;
                        } catch (Exception var15) {
                           var10000 = var15;
                           var10001 = false;
                           break label174;
                        }

                        var30 = var40;

                        try {
                           var40.<init>();
                           var39 = var38.crls.iterator();
                        } catch (Exception var14) {
                           var10000 = var14;
                           var10001 = false;
                           break label174;
                        }

                        Iterator var33 = var39;

                        while(true) {
                           try {
                              var41 = var33.hasNext();
                           } catch (Exception var12) {
                              var10000 = var12;
                              var10001 = false;
                              break label174;
                           }

                           if (!var41) {
                              try {
                                 var47 = var5;
                                 var42 = new DERSet;
                              } catch (Exception var11) {
                                 var10000 = var11;
                                 var10001 = false;
                                 break label174;
                              }

                              DERSet var34 = var42;

                              try {
                                 var42.<init>(var30);
                                 var47.add(new DERTaggedObject(false, 1, var34));
                                 break;
                              } catch (Exception var10) {
                                 var10000 = var10;
                                 var10001 = false;
                                 break label174;
                              }
                           }

                           try {
                              var30.add((new ASN1InputStream(new ByteArrayInputStream(((X509CRL)var33.next()).getEncoded()))).readObject());
                           } catch (Exception var13) {
                              var10000 = var13;
                              var10001 = false;
                              break label174;
                           }
                        }
                     }

                     try {
                        var5.add(new DERSet(new DERSequence(var3)));
                        var47 = new ASN1EncodableVector;
                     } catch (Exception var9) {
                        var10000 = var9;
                        var10001 = false;
                        break label174;
                     }

                     var40 = var47;
                     var10002 = var30 = var47;

                     DERTaggedObject var48;
                     try {
                        var10002.<init>();
                        var40.add(new DERObjectIdentifier("1.2.840.113549.1.7.2"));
                        var48 = new DERTaggedObject;
                     } catch (Exception var8) {
                        var10000 = var8;
                        var10001 = false;
                        break label174;
                     }

                     DERTaggedObject var43 = var48;
                     byte var44 = 0;

                     ByteArrayOutputStream var49;
                     try {
                        var43.<init>(var44, new DERSequence(var5));
                        var47.add(var48);
                        var49 = new ByteArrayOutputStream;
                     } catch (Exception var7) {
                        var10000 = var7;
                        var10001 = false;
                        break label174;
                     }

                     ByteArrayOutputStream var36;
                     ByteArrayOutputStream var50 = var36 = var49;

                     try {
                        var50.<init>();
                        DEROutputStream var51 = new DEROutputStream(var36);
                        var51.writeObject(new DERSequence(var30));
                        var51.close();
                        return var49.toByteArray();
                     } catch (Exception var6) {
                        var10000 = var6;
                        var10001 = false;
                        break label174;
                     }
                  }

                  try {
                     var3.add((new ASN1InputStream(new ByteArrayInputStream(((X509Certificate)var4.next()).getEncoded()))).readObject());
                  } catch (Exception var21) {
                     var10000 = var21;
                     var10001 = false;
                     break label174;
                  }
               }
            }

            try {
               var1.add(new AlgorithmIdentifier(new DERObjectIdentifier((String)var2.next()), (DEREncodable)null));
            } catch (Exception var27) {
               var10000 = var27;
               var10001 = false;
               break;
            }
         }
      }

      Exception var31 = var10000;
      throw new RuntimeException(var31.toString());
   }
}
